/**
 * @param {Schema} schema
 * @param {string} defaultTagName
 * @param {Array.<string>} [caseSensitive]
 */
export function core(
  schema: Schema,
  defaultTagName: string,
  caseSensitive?: string[] | undefined
): {
  (): HastRoot
  (selector: null | undefined, ...children: HChild[]): HastRoot
  (
    selector: string,
    properties: HProperties,
    ...children: HChild[]
  ): HastElement
  (selector: string, ...children: HChild[]): HastElement
}
export type HastRoot = import('hast').Root
export type HastElement = import('hast').Element
export type Properties = import('hast').Properties
export type HastChild = HastRoot['children'][number]
export type Info = import('property-information/lib/util/schema').Schema['property'][string]
export type Schema = typeof import('property-information').html
export type HResult = HastRoot | HastElement
export type HStyleValue = string | number
export type HStyle = {
  [x: string]: HStyleValue
}
export type HPrimitiveValue = string | number | boolean | null | undefined
export type HArrayValue = Array<string | number>
export type HPropertyValue = HPrimitiveValue | (string | number)[]
export type HProperties = {
  [property: string]:
    | {
        [x: string]: HStyleValue
      }
    | HPropertyValue
}
export type HPrimitiveChild = string | number | null | undefined
export type HNodeChild = HastChild | HastRoot
export type HArrayChild = Array<HPrimitiveChild | HNodeChild>
export type HChild =
  | HPrimitiveChild
  | HNodeChild
  | (HPrimitiveChild | HNodeChild)[]
